<?php

class Woo_options{

  protected static $profiles = array();
  protected static $options = array(
    'SIRV_WOO_IS_ENABLE' => array(
      'option_name' => 'SIRV_WOO_IS_ENABLE',
      'label' =>'Sirv Media Viewer',
      //'desc' => 'Some text here',
      'type' => 'radio',
      'value' => '',
      'values' => array(
        array(
          'label' => 'Disabled',
          'value' => '1'
        ),
        array(
          'label' => 'Enabled',
          'value' => '2'
        )

      ),
      'default' => '1',
      'show_status' => true,
      'enabled_value' => '2',
    ),
    'SIRV_WOO_CONTENT_ORDER' => array(
      'option_name' => 'SIRV_WOO_CONTENT_ORDER',
      'label' =>'Order of Sirv content',
      'type' => 'radio',
      'value' => '',
      'values' => array(
        array(
          'label' => 'Before Woocommerce images',
          'value' => '1'
        ),
        array(
          'label' => 'After Woocommerce images',
          'value' => '2'
        ),
        array(
          'label' => 'Show Sirv content only',
          'value' => '3'
        ),
      ),
      'default' => '2',
      'show_status' => false,
    ),
    'SIRV_WOO_SHOW_VARIATIONS' => array(
      'option_name' => 'SIRV_WOO_SHOW_VARIATIONS',
      'label' =>'Number of images',
      'type' => 'radio',
      'value' => '',
      'values' => array(
        array(
          'label' => 'Show all images',
          'value' => '1'
        ),
        array(
          'label' => 'Show images for current combination only',
          'value' => '2'
        )
      ),
      'default' => '2',
      'show_status' => false,
    ),
    'SIRV_WOO_PRODUCTS_PROFILE' => array(
      'option_name' => 'SIRV_WOO_PRODUCTS_PROFILE',
      'label' =>'Product images profile',
      'tooltip' => 'Apply one of <a target="_blank" href="https://my.sirv.com/#/profiles/">your profiles</a> for watermarks, text and other image customizations. Learn <a target="_blank" href="https://sirv.com/help/articles/dynamic-imaging/profiles/">about profiles</a>.',
      'type' => 'select',
      'select_id' => 'sirv-woo-product-profiles',
      'hidden_id' => 'sirv-woo-product-profiles-val',
      'value' => '',
      'default' => ''
    ),
    'SIRV_WOO_MV_CONTAINER_CUSTOM_CSS' =>array(
      'option_name' => 'SIRV_WOO_MV_CONTAINER_CUSTOM_CSS',
      'label' =>'Container custom CSS',
      //'desc' => 'Some text here',
      'type' => 'textarea',
      'value' => '',
      'placeholder' => 'Add styles to adjust size/position of Sirv Media Viewer container:

width: 49%;
float: left;',
      'size' => '5',
      'default' => '',
    ),
    'SIRV_WOO_MV_CUSTOM_OPTIONS' => array(
      'option_name' => 'SIRV_WOO_MV_CUSTOM_OPTIONS',
      'label' =>'Media Viewer options',
      //'desc' => 'Some text here',
      'type' => 'textarea',
      'value' => '',
      'placeholder' => "Add custom js options for Media Viewer. e.g.
var SirvOptions = {
  zoom: {
    mode: 'deep'
  }
}",
      'below_desc' => 'Change the zoom, spin, video and thumbnail options with JavaScript. See <a href="https://sirv.com/help/articles/sirv-media-viewer/#options">list of options</a>.',
      'tooltip' => 'Change the zoom, spin, video and thumbnail options with JavaScript. See <a target="_blank" href="https://sirv.com/help/articles/sirv-media-viewer/#options">list of options</a>.',
      'size' => '6',
      'default' => '',
    ),

  );


  public static function get_option_names_list(){
    $names = array();

    foreach (self::$options as $option_name => $option_data) {
      $names[] = $option_name;
    }

    return $names;
  }


  public static function register_settings(){
    foreach (self::$options as $option_name => $option_data) {
      register_setting( 'sirv-woo-settings-group', $option_name);
      if ( !get_option($option_name) ) update_option($option_name, $option_data['default']);
    }
  }


  public static function render_options($profiles){
    $html = '';
    self::$profiles = $profiles;
    self::update_options_values();

    foreach (self::$options as $option_name => $option_data) {
      $html .= self::get_item($option_data);
    }

    return $html;
  }


  protected static function get_item($data){
    $item = '';
    switch ($data['type']) {
      case 'radio':
        $item = self::render_radio($data);
        break;
      case 'select':
        $item = self::render_select($data);
        break;
      case 'checkbox':
        $item = self::render_checkbox($data);
        break;
      case 'input':
        $item = self::render_input($data);
        break;
      case 'textarea':
        $item = self::render_textarea($data);
        break;

      default:
        # code...
        break;
    }

    return $item;
  }


  protected static function update_options_values(){
    foreach (self::$options as $option_name => $option_data) {
      $cur_value = !get_option($option_name) ? $option_data['default'] : get_option($option_name);
      self::$options[$option_name]['value'] = $cur_value;
    }
  }


  protected static function render_select($item){
    $html = '
    <tr>
      <th>
        <label>'. $item['label'] .'</label>
      </th>
      <td>
        <select id="'. $item['select_id'] .'">
          <option disabled>Choose profile</option>'
          . self::render_select_items($item) .'
        </select>
        <input type="hidden" id="'. $item['hidden_id'] .'" name="'. $item['option_name'] .'" value="'. $item['value'] .'">
      </td>'. PHP_EOL . self::tooltip($item) .'
    </tr>';

    return $html;
  }


  protected static function render_select_items($data){
    $default_selected = ($data['value'] == '') ? 'selected' : '';
    $select_items = '<option value="" '. $default_selected .'>-</option>';

    foreach (self::$profiles as $profile) {
      $select_items .= "<option value='{$profile}' ". selected( $profile, $data['value'], false ) .">{$profile}</option>". PHP_EOL;
    }

    return $select_items;
  }


  protected static function render_radio($item){
    $html = '
    <tr>
      <th>
        <label>'. $item['label'] .'</label>
      </th>
      <td>' . self::get_radio_items($item) .
      '</td>' . PHP_EOL . self::tooltip($item);

    if($item['show_status']){
      $status_class = $item['value'] == $item['enabled_value'] ? 'sirv-status--enabled' : 'sirv-status--disabled';
      $html .= '
        <td>
          <span class="sirv-status '. $status_class .'"></span>
        </td>
      </tr>' . PHP_EOL;
    }else{
      $html .= '<tr>' . PHP_EOL;
    }

    return $html;
  }


  protected static function get_radio_items($data){
    $radio_items = '';

    foreach ($data['values'] as $radio_item) {
      $radio_items .= '<label><input type="radio" name="'. $data['option_name'] .'"
      value="'. $radio_item['value']. '" '. checked( intval($radio_item['value']), $data['value'], false ) .' >'. $radio_item['label'] .'</label><br />'. PHP_EOL;
    }

    return $radio_items;
  }


  protected static function render_checkbox($item){
    $html = '
    <tr>
      <th>
        <label>'. $item['label'] .'</label>
      </th>
      <td>
        <label><input type="checkbox" name="'. $item['option_name'] .'" id="'. $item['option_name'] .'" value="1" '. checked('1', $item['value'], false ) .' >
          <span class="sirv-option-responsive-text">'. $item['desc'] .'</span>
        </label>
      </td>'. PHP_EOL . self::tooltip($item) .'
    </tr>';

    return $html;
  }


  protected static function render_input($item){
    $html = '';

    return $html;
  }


  protected static function render_textarea($item){

    $html = '
    <tr>
      <th>
        <label>'. $item['label'] .'</label>
      </th>
      <td>
        <textarea name="'. $item['option_name'] .'" placeholder="'. $item['placeholder'] .'" value="'. $item['value'] .'" rows="'.$item['size'].'">'. $item['value'] .'</textarea>
      </td>'. PHP_EOL . self::tooltip($item) .'
    </tr>';

    return $html;
  }

  protected static function tooltip($item){
    $tooltip = '';
    if( isset($item['tooltip']) ){
      $tooltip= '
      <td>
        <div class="sirv-tooltip">
          <i class="dashicons dashicons-editor-help sirv-tooltip-icon"></i>
          <span class="sirv-tooltip-text sirv-no-select-text">'. $item['tooltip'] .'</span>
        </div>
      </td>
      ';
    }

    return $tooltip;
  }


}

?>
